<?php
// WizyTówka 4
if (!defined('WT')) exit();


// funkcje modyfikujące ciągi znaków

// funkcja poprawiająca typografię tekstu i parsująca Markdown, jeśli jest taka potrzeba

function tekst( $tekst, $uzywacMarkdown = false, $zamienEncje = false ) {

	if ( $uzywacMarkdown and odczytKonf('jezykMarkdown') ) {
		include_once('markdown.php');
		$tekst = Markdown($tekst);
	}

	$tekst = ' ' . $tekst . ' ';   // poprawne działanie mechanizmów poprawiających typografię

	if ( odczytKonf('typografiaCudzyslowy') ) {

		$cudzyslowy = array(
			// cudzysłów otwierający:
			' "' => ' &bdquo;', '>"' => '>&bdquo;', '("' => '(&bdquo;', '..."' => '...&bdquo;', "\n\"" => "\n&bdquo;",
			// cudzysłów zamykający:
			'" ' => '&rdquo; ', '"<' => '&rdquo;<', '")' => '&rdquo;)', '"...' => '&rdquo;...', '\"\n' => "&rdquo;\n",
			'",' => '&rdquo;,', '";' => '&rdquo;;', '"!' => '&rdquo;!', '"?' => '&rdquo;?', '".' => '&rdquo;.'
		);

		$tekst = str_replace( '&quot;', '"', $tekst );

		if ( strpos($tekst,'<') !== false and strpos($tekst,'>') !== false ) {

			preg_match_all ( '/>[^>]*</i', '>'.$tekst.'<', $fragmentyHTML );
				//  podziękowania za pomoc dla soanviga   z webax.pl

			foreach ( $fragmentyHTML as $fragment )
				$tekst = str_replace( $fragment, zastepowanie($fragment,$cudzyslowy), $tekst );

		}
		else
			$tekst = zastepowanie( $tekst, $cudzyslowy );

	}

	if ( odczytKonf('typografiaInne') ) {

		$m = ( odczytKonf('typografiaPolpauza') ) ? 'n' : 'm';

		$inneZnaki = array(
			// myślnik/pauza:
			' - '  => ' &'.$m.'dash; ', '>- ' => '>&'.$m.'dash; ', ' -<' => ' &'.$m.'dash;<',
			// wielokropek:
			'... ' => '&hellip; ', ' ...' => ' &hellip;', "...\n" => "&hellip;\n", "\n..." => "\n&hellip;",
			'>...' => '>&hellip;', '...<' => '&hellip;<',
			// apostrof:
			"'" => '&rsquo;'
		);

		$tekst = zastepowanie( $tekst, $inneZnaki );

	}

	if ( odczytKonf('typografiaSpojniki') ) {

		$spojniki = array(
			'(o ' => '(o&nbsp;', '(u ' => '(u&nbsp;', '(w ' => '(w&nbsp;', '(z ' => '(z&nbsp;', '(i ' => '(i&nbsp;', '(a ' => '(a&nbsp;',
			' o ' => ' o&nbsp;', ' u ' => ' u&nbsp;', ' w ' => ' w&nbsp;', ' z ' => ' z&nbsp;', ' i ' => ' i&nbsp;', ' a ' => ' a&nbsp;',
			' O ' => ' O&nbsp;', ' U ' => ' U&nbsp;', ' W ' => ' W&nbsp;', ' Z ' => ' Z&nbsp;', ' I ' => ' I&nbsp;', ' A ' => ' A&nbsp;',
		);

		$tekst = zastepowanie( $tekst, $spojniki );

	}

	return ($zamienEncje) ? html_entity_decode( substr($tekst,1,-1), null, 'UTF-8' ) : substr($tekst,1,-1);

}

// wyświetlanie daty według formatu określonego w konfiguracji

function pokazDate ( $czasUniksowy, $formatDaty = null ) {

	if ( !is_numeric($czasUniksowy) )
		return false;

	if ( empty($formatDaty) )
		$formatDaty = odczytKonf('formatDaty');

	// w Windows nie działa modyfikator %e (dzień miesiąca bez zer wiodących)
	if ( isset($_SERVER['WINDIR']) and strpos($formatDaty,'%e') !== false )
		$formatDaty = str_replace( '%e', date('j',$czasUniksowy), $formatDaty );

	// na niektórych serwerach lokalizacjach jest błąd; w dacie zawsze miesiąc powinien być w dopełniaczu
	if ( strpos($formatDaty,'%B') !== false and (substr(strftime('%B'),-1) != 'a' and substr(strftime('%B'),-1) != 'o') ) {

		$miesiaceWDopelniaczu = array(
			'styczeń' => 'stycznia', 'luty' => 'lutego', 'marzec' => 'marca', 'kwiecień' => 'kwietnia',
			'maj' => 'maja', 'czerwiec' => 'czerwca', 'lipiec' => 'lipca', 'sierpień' => 'sierpnia',
			'wrzesień' => 'września', 'październik' => 'października', 'listopad' => 'listopada', 'grudzień' => 'grudnia'
		);

		$data = strftime($formatDaty,$czasUniksowy);

		if ( mb_check_encoding($data) )
			return zastepowanie( $data, $miesiaceWDopelniaczu );
		else
			return zastepowanie( iconv( 'ISO-8859-2', 'UTF-8', $data ), $miesiaceWDopelniaczu );

	}

	return strftime($formatDaty,$czasUniksowy);

}

// sprawdzanie poprawności adresu witryny

function sprawdzAdres ( $ciag ) {

	if ( empty($ciag) )
		return false;
	return preg_match ( '/^(http|https)\:\/\/[a-zA-Z0-9\.\-_\/:]+$/', $ciag );

}

// sprawdzanie poprawności adresu e-mail

function sprawdzEmail ( $ciag ) {

	if ( empty($ciag) )
		return false;
	return preg_match ( '/^[a-zA-Z0-9\.\-_]+@[a-zA-Z0-9\.\-_]+\.[a-zA-Z0-9\.\-_]{2,4}$/', $ciag );

}

// sprawdzanie poprawności identyfikatora lub nazwy pliku

function sprawdzNazwe ( $ciag ) {

	if ( empty($ciag) or $ciag[0] == '.' or is_numeric($ciag) )
		return false;
	return preg_match ( '/^[a-zA-Z0-9.\-\_]+$/', $ciag );

}

// usuwanie zbędnych znaków z nazwy pliku (patrz: funkcja wyżej)

function prostaNazwa ( $ciag, $maleLitery = true ) {

	if ( empty($ciag) )
		return '-';

	$znakiDiakrytyczne = array(
		'ą' => 'a', 'ć' => 'c', 'ę' => 'e', 'ł' => 'l', 'ń' => 'n', 'ś' => 's', 'ó' => 'o', 'ż' => 'z', 'ź' => 'z',
		'Ą' => 'A', 'Ć' => 'C', 'Ę' => 'E', 'Ł' => 'L', 'Ń' => 'N', 'Ś' => 'S', 'Ó' => 'O', 'Ż' => 'Z', 'Ź' => 'Z'
	);
	$ciag = zastepowanie( $ciag, $znakiDiakrytyczne );

	$znakiSpecialne = array(
		',', '/', "'", '"', "\\", '!', '?', '@', '$', '%', '&', '*',
		'(', ')', '[', ']', '<', '>', '{', '}', '=', '+', ':', ';'
	);
	$ciag  = str_replace( $znakiSpecialne, null, $ciag );

	$ciag  = str_replace( ' ', '-', $ciag );

	if ( $maleLitery )
		$ciag = strtolower( $ciag );

	return $ciag;

}

// zastępowanie jednych ciągów znaków innymi z tablicy

function zastepowanie ( $ciag, $tablicaZastepowania ) {

	foreach ( $tablicaZastepowania as $oryginal => $zamiennik )
		$ciag = str_replace( $oryginal, $zamiennik, $ciag );

	return $ciag;

}

// zmienne w formie %nazwa%, tablica

function zmienne ( $ciag, $zmienne ) {

	foreach ( $zmienne as $nazwa => $wartosc ) {
		$nazwyZmiennych[] = '%' . $nazwa . '%';
		$wartosciZmiennych[] = $wartosc;
	}

	return str_replace( $nazwyZmiennych, $wartosciZmiennych, $ciag );

}

// mechanizm sortujący tablicę według jednego z jej elementów

function sortowanie ( $tablicaDoPosortowania, $elementSortujacy, $odwrocenie = false ) {

	if ( empty($tablicaDoPosortowania) )
		return array();

	foreach ( $tablicaDoPosortowania as $klucz => $zawartosc )
		$tablicaRobocza[$klucz] = $zawartosc[$elementSortujacy];

	if ( !is_numeric($zawartosc[$elementSortujacy]) )
		asort( $tablicaRobocza, SORT_LOCALE_STRING );
	else
		asort( $tablicaRobocza );

	foreach ( $tablicaRobocza as $klucz => $posortowanaWartosc )
		$tablicaPosortowana[$klucz] = $tablicaDoPosortowania[$klucz];

	return ( $odwrocenie ) ? array_reverse( $tablicaPosortowana, true ) : $tablicaPosortowana;

}

// wycinanie początkowego fragmentu tekstu według liczby znaków lub słów

function fragment( $ciag, $iloscZnakow, $wedlugSlow = false ) {

	$ciag = usunZnakNowejLinii($ciag);

	if ( $wedlugSlow ) {

		$slowa = explode( ' ', $ciag, $iloscZnakow+1 );

		if ( $iloscZnakow < count($slowa) ) {
			unset( $slowa[count($slowa)-1] );
			$dodajWielokropek = true;
		}

		$ciag = implode( ' ', $slowa );

		if ( isset($dodajWielokropek) )
			$ciag .= '…';

	}

	else {

		if ( mb_strlen($ciag) > $iloscZnakow )
			$ciag = trim( mb_substr( $ciag, 0, $iloscZnakow ) ) . '…';

	}

	return $ciag;

}

// funkcja ograniczająca znaczniki HTML tylko do dozwolonych

function ograniczonyHTML ( $ciag ) {

	return usunZnakNowejLinii( strip_tags( htmlspecialchars_decode($ciag), '<a><strong><em><u><b><i><s><span><br><img>' ) );

}

// nazwa tej funkcji chyba mówi sama za siebie

function usunZnakNowejLinii ( $ciag ) {

	return str_replace( array("\n","\r",'   ','  '), ' ', $ciag );

}

// jak mi się coś buguje, to z tym walczę...

function debuguj ( $niewiadomoco, $zatrzymaj = true ) {

	echo '<pre>';
	var_dump($niewiadomoco);
	echo '</pre>';

	if ($zatrzymaj)
		exit();

}