<?php
// WizyTówka 4
if (!defined('WT')) exit();


// funkcje odczytu danych strony

// pamięć podręczna (używana do ograniczenia otwierania plików i komunikacji między funkcjami)

function pamiecPodreczna ( $tablica = null, $nazwa = null ) {

	static $pamiecPodreczna = array();

	if ( is_string($tablica) ) {
		if ( isset( $pamiecPodreczna[$tablica] ) )
			return $pamiecPodreczna[$tablica];
		else
			return false;
	}

	elseif ( is_array($tablica) and !empty($nazwa) )
		$pamiecPodreczna[$nazwa] = $tablica;

    elseif ( empty($tablica) )
        return $pamiecPodreczna;

}

// odczyt głównego pliku konfiguracyjnego

function odczytKonf ( $ustawienia = null ) {

	if ( !pamiecPodreczna( 'konfiguracja' ) ) {
		if ( !$plikKonf = file_get_contents( DANE . '/wtk/konfiguracja.wtk' ) ) {
			define( 'BLEDY_KRYTYCZNE', 1 );
			trigger_error( 'Plik konfiguracyjny jest uszkodzony.', E_USER_WARNING );
		}
		if ( !$jawnyPlikKonf = unserialize( $plikKonf ) ) {
			define( 'BLEDY_KRYTYCZNE', 1 );
			trigger_error( 'Tablica pliku konfiguracyjnego jest uszkodzona.', E_USER_WARNING );
		}
		pamiecPodreczna( $jawnyPlikKonf, 'konfiguracja' );
	}
	$odczyt = pamiecPodreczna( 'konfiguracja' );

	if ( empty( $ustawienia ) )
		return $odczyt;
	elseif ( is_string( $ustawienia ) )
		return $odczyt[$ustawienia];
	elseif ( is_array( $ustawienia ) ) {
		foreach ( $ustawienia as $u )
			$tablica[$u] = $odczyt[$u];
		return $tablica;
	}

}

// zapis głównego pliku konfiguracyjnego

function zapisKonf ( $ustawienia, $WTK = false ) {

	$konfiguracjaZmodyfikowana = (!$WTK) ? array_replace ( odczytKonf(), $ustawienia ) : $ustawienia;

	pamiecPodreczna( $konfiguracjaZmodyfikowana, 'konfiguracja' );
	file_put_contents( DANE . '/wtk/konfiguracja.wtk', serialize( $konfiguracjaZmodyfikowana ), LOCK_EX );

}

// odczyt pliku w formacie WTK

function odczytPlikuWTK ( $nazwaPliku ) {

	if ( ($jawnyPlikWTK = unserialize( file_get_contents( DANE . ((strpos($nazwaPliku,'/')===false) ? '/wtk/' : '/') . $nazwaPliku ) )) === false )
		trigger_error( 'Tablica pliku WTK "' . $nazwaPliku . '" jest uszkodzona.', E_USER_WARNING );

	return $jawnyPlikWTK;

}

// zapis pliku w formacie WTK

function zapisPlikuWTK ( $ustawienia, $nazwaPliku, $laczenie = true ) {

	if ( $laczenie ) {

		$plikDotychczasowy = unserialize( file_get_contents( DANE . ((strpos($nazwaPliku,'/')===false) ? '/wtk/' : '/') . $nazwaPliku ) );
		$plikZmodyfikowany = array_replace( $plikDotychczasowy, $ustawienia );

		file_put_contents( DANE . ((strpos($nazwaPliku,'/')===false) ? '/wtk/' : '/') . $nazwaPliku, serialize($plikZmodyfikowany), LOCK_EX );

	}

	else
		file_put_contents( DANE . ((strpos($nazwaPliku,'/')===false) ? '/wtk/' : '/') . $nazwaPliku, serialize($ustawienia), LOCK_EX );

}

// tablica wszystkich przesłanych plików

function listaPlikow ( $rozszerzenia = null ) {

	$wszystkiePliki = glob( odczytKonf('adresPlikow') . '/*' );

	if ( !empty($wszystkiePliki) ) {

		$wszystkiePliki = array_map ( 'basename', $wszystkiePliki );
		foreach ( $wszystkiePliki as $klucz => $element ) {
			if ( is_dir( odczytKonf('adresPlikow') . '/' . $element ) )
				unset( $wszystkiePliki[$klucz] );
		}

		if ( !empty($rozszerzenia) ) {

			$rozszerzenia = explode( ';', $rozszerzenia );
			$filtr = array();

			foreach ( $wszystkiePliki as $tenPlik ) {
				$rozszerzenieTegoPliku = strtolower( substr( $tenPlik, strrpos($tenPlik,'.')+1 ) );
				foreach ( $rozszerzenia as $koncowka ) {
					if ( $koncowka == $rozszerzenieTegoPliku )
						$filtr[] = $tenPlik;
				}
			}

			$wszystkiePliki = $filtr;

		}

	}

	if ( $wszystkiePliki === false )
		$wszystkiePliki = array();

	return $wszystkiePliki;

}

// tablica wszystkich utworzonych stron / szkiców stron

function listaStron ( $szkice = false ) {

	$wszystkieStrony = glob( DANE . '/' . (($szkice) ? 'szkice' : 'strony') . '/*.wtk' );

	if ( !empty($wszystkieStrony) ) {
		foreach ( $wszystkieStrony as $klucz => $element )
			$wszystkieStrony[$klucz] = substr( basename($element), 0, strrpos(basename($element),'.') );
	}
	elseif ( !$szkice )
		trigger_error( 'Nie istnieją żadne strony!', E_USER_WARNING );

	return $wszystkieStrony;

}

// odczyt strony o podanym identyfikatorze

function odczytStrony ( $identyfikator, $szkic = false, $zawartoscZamiastUstawien = false ) {

	if ( !file_exists( DANE . '/' . (($szkic) ? 'szkice' : 'strony') . '/' . $identyfikator . '.wtk' ) )
		return false;

	return odczytPlikuWTK( (($szkic) ? 'szkice' : 'strony') . '/' . $identyfikator . '.' . (($zawartoscZamiastUstawien) ? 'wtz' : 'wtk') );

}

// odczyt typu zawartości strony lub motywu (mają podobną strukturę, wrzuciłem w jedną funkcję ;->)

function odczytTypuMotywu ( $element, $identyfikator ) {

	if ( $element != 'typy' and $element != 'motywy' )
		return false;

	if     ( file_exists( DANE   . '/' . $element . '/' . $identyfikator . '/' . $identyfikator . '.wtu' ) )
		$wlasny = true;
	elseif ( file_exists( SYSTEM . '/' . $element . '/' . $identyfikator . '/' . $identyfikator . '.wtu' ) )
		$wlasny = false;
	else
		return false;

	if ( $wlasny ) {
		if ( $element == 'typy' ) {
			$ustawieniaDom = array(
				'informacje' => array( 'ustawienia' => 0, 'znacznikHEAD' => 0, 'naglowkiHTTP' => 0 ),
				'ustawieniaDomyslne' => array(),
				'zawartoscDomyslna' => array()
			);
		}
		elseif ( $element == 'motywy' ) {
			$ustawieniaDom = array(
				'informacje' => array( 'responsywnosc' => 0, 'edytorWizualny' => 0, 'krojGoogleFonts' => 0 ),
				'mozliwosci' => array( 'menuGlowne' => 0, 'menuDodatkowe' => 0, 'obszarBoczny' => 0, 'obszarDodatkowy' => 0, 'logo' => 0, 'haslo' => 0 ),
				'personalizacja' => array( 'kolorTla' => 0, 'obrazTla' => 0, 'kolorTekstu' => 0, 'krojTekstu' => 0, 'rozmiarTekstu' => 0, 'szerokosc' => 0, 'koloryDodatkowe' => 0 ),
				'koloryDodatkowe' => array( '1_nazwa' => '', '1_CSS' => '', '2_nazwa' => '', '2_CSS' => '' )
			);
		}
		$ustawieniaDom['wlasny'] = true;
	}
	else
		$ustawieniaDom = array( 'wlasny' => false );

	if ( !$tablicaUstawien = parse_ini_file( (($wlasny) ? DANE : SYSTEM ) . '/' . $element . '/' . $identyfikator . '/' . $identyfikator . '.wtu', true) )
		trigger_error( 'Plik WTU motywu lub typu "' . $identyfikator . '" jest uszkodzony.', E_USER_WARNING );

	unset($tablicaUstawien['wlasny']);

	return array_replace_recursive( $ustawieniaDom, $tablicaUstawien );

}

// wysyłanie wiadomości e-mail na podany w konfiguracji adres

function wiadomosc( $tresc, $temat ) {

	if ( odczytKonf('email') == null ) {
		trigger_error( 'Brak adresu e-mail przy wysyłaniu wiadomości.', E_USER_NOTICE );
		return false;
	}

	$temat .= ' — ' . tekst( odczytKonf('tytul'), false, true );
	$tresc .= "\n\n" . '________________________________________' . "\n" . odczytKonf('adres');

	$poszukiwanieDomeny = explode( '/', odczytKonf('adres'), 4 );
	$naglowki = 'From: wizytowka@' . $poszukiwanieDomeny[2] . "\r\n" . 'Content-type: text/plain; charset=UTF-8';

	if (  mb_send_mail( odczytKonf('email'), $temat, wordwrap($tresc,70) )  ) {
		zapisKonf( array( 'wiadomoscEmailNiepomyslnie' => '' ) );
		return true;
	}
	else {
		zapisKonf( array( 'wiadomoscEmailNiepomyslnie' => time() ) );
		return false;
	}

}

// sprawdzenie, czy autor jest zalogowany

function zalogowany() {

	if ( !isset($_COOKIE['WT_administracja']) or odczytKonf('identyfikatorLogowania') == '' )
		return false;

	else {

		include_once( SYSTEM . '/funkcje/password.php' );

		return ( password_verify( $_COOKIE['WT_administracja'].$_SERVER['REMOTE_ADDR'], odczytKonf('identyfikatorLogowania') ) ) ? true : false;

	}

}

// ładne mierzenie rozmiaru pliku

function rozmiarPliku ( $nazwaPliku ) {

	$rozmiar = filesize( odczytKonf('adresPlikow') . '/' . $nazwaPliku );

	if ( $rozmiar < 1024 )
		$jednostka = 'B';
	elseif ( $rozmiar < 1024 * 1024 ) {
		$rozmiar = $rozmiar / 1024;
		$jednostka = 'KiB';
	}
	else {
		$rozmiar = $rozmiar / 1024 / 1024;
		$jednostka = 'MiB';
	}

	return round( $rozmiar, 2 ) . ' ' . $jednostka;

}
